@@ -3,7 +3,7 @@ import os
 import re
 import openpyxl
 import numpy as np
-from line_profiler_pycharm import profile
+# from line_profiler_pycharm import profile
 
 INSTRUCTOR_ROW = 6
 INSTRUCTOR_CHECKER_ROW = 31
